@@ -2,7 +2,7 @@
 
 
 package HiD::App::Command::config;
-$HiD::App::Command::config::VERSION = '1.95_91';
+$HiD::App::Command::config::VERSION = '1.95_92';
 use Moose;
 extends 'HiD::App::Command';
 use namespace::autoclean;
@@ -14,7 +14,7 @@ use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
 
-use Data::Printer;
+use Data::Printer return_value => 'dump';
 
 sub _run {
   my( $self , $opts , $args ) = @_;
@@ -68,7 +68,7 @@ sub commands.
 
 =head1 VERSION
 
-version 1.95_91
+version 1.95_92
 
 =head1 AUTHOR
 
